… | OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
   1. 1 Commercial manned guarding
   2. Ω Jūsu pievienotie riski
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Neatbildēts
   - Atlikts jautājums
   - Viss kārtībā
   - Uzmanību
4. Rīcības plāns
5. Pārskats
6. Statuss 0%

## Aprakstiet risku…

Nē, ir nepieciešams vairāk pasākumu Jā, atlikušais risks ir pieņemams

Select the priority of this risk Low Medium High
Informācija
label_upload_image
Komentāri

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More